#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2018-01-02
#
# Check Point Identity Awareness metrics plugin
# checkpoint_identity_awareness
#

from cmk.gui.i18n import _

from cmk.gui.plugins.metrics import (
    metric_info,
    graph_info,
    perfometer_info,
)

metric_info['checkpoint_identity_awareness_iaSuccUserLoginADQuery'] = {
    'title': _('Successfull ADQuery user login attempts'),
    'unit': 'count',
    'color': '11/a',
}
metric_info['checkpoint_identity_awareness_iaSuccMachLoginADQuery'] = {
    'title': _('Successfull ADQuery machine login attempts'),
    'unit': 'count',
    'color': '13/a',
}
metric_info['checkpoint_identity_awareness_iaSuccUserLoginKerberos'] = {
    'title': _('Successfull Kerberos user login attempts'),
    'unit': 'count',
    'color': '15/a',
}
metric_info['checkpoint_identity_awareness_iaSuccMachLoginKerberos'] = {
    'title': _('Successfull Kerberos machine login attempts'),
    'unit': 'count',
    'color': '21/a',
}
metric_info['checkpoint_identity_awareness_iaSuccUserLoginPass'] = {
    'title': _('Successfull User Name And Password login attempts'),
    'unit': 'count',
    'color': '23/a',
}
metric_info['checkpoint_identity_awareness_iaUnSuccUserLoginKerberos'] = {
    'title': _('Unsuccessfull Kerberos user login attempts'),
    'unit': 'count',
    'color': '25/a',
}
metric_info['checkpoint_identity_awareness_iaUnSuccMachLoginKerberos'] = {
    'title': _('Unsuccessfull Kerberos machine login attempts'),
    'unit': 'count',
    'color': '31/a',
}
metric_info['checkpoint_identity_awareness_iaUnSuccUserLoginPass'] = {
    'title': _('Unsuccessfull User Name And Password login attempts'),
    'unit': 'count',
    'color': '43/a',
}

metric_info['checkpoint_identity_awareness_iaSuccUserLDAP'] = {
    'title': _('Successful LDAP queries'),
    'unit': '1/s',
    'color': '11/b',
}
metric_info['checkpoint_identity_awareness_iaUnSuccUserLDAP'] = {
    'title': _('Unsuccessful LDAP queries'),
    'unit': '1/s',
    'color': '21/b',
}

metric_info['checkpoint_identity_awareness_iaAuthUsers'] = {
    'title': _('Authenticated users to the gateway'),
    'unit': 'count',
    'color': '12/a',
}
metric_info['checkpoint_identity_awareness_iaAuthUsersADQuery'] = {
    'title': _('Authenticated users by ADQuery'),
    'unit': 'count',
    'color': '14/a',
}
metric_info['checkpoint_identity_awareness_iaAuthMachADQuery'] = {
    'title': _('Authenticated machines by ADQuery'),
    'unit': 'count',
    'color': '16/a',
}
metric_info['checkpoint_identity_awareness_iaAuthUsersKerberos'] = {
    'title': _('Authenticated users by Kerberos'),
    'unit': 'count',
    'color': '22/a',
}
metric_info['checkpoint_identity_awareness_iaAuthMachKerberos'] = {
    'title': _('Authenticated machines by Kerberos'),
    'unit': 'count',
    'color': '24/a',
}
metric_info['checkpoint_identity_awareness_iaAuthUsersPass'] = {
    'title': _('Authenticated users by User name and password'),
    'unit': 'count',
    'color': '26/a',
}
metric_info['checkpoint_identity_awareness_iaUnAuthUsers'] = {
    'title': _('Unauthenticated guests'),
    'unit': 'count',
    'color': '32/a',
}

metric_info['checkpoint_identity_awareness_iaLoggedInADQuery'] = {
    'title': _('Identities logged in with ADQuery'),
    'unit': 'count',
    'color': '12/a',
}
metric_info['checkpoint_identity_awareness_iaLoggedInAgent'] = {
    'title': _('Identities logged in with agents'),
    'unit': 'count',
    'color': '14/a',
}
metric_info['checkpoint_identity_awareness_iaLoggedInCaptivePortal'] = {
    'title': _('Identities logged in with Captive Portal'),
    'unit': 'count',
    'color': '16/a',
}
metric_info['checkpoint_identity_awareness_iaRADIUSAccounting'] = {
    'title': _('Identities logged in with RADIUS Accounting'),
    'unit': 'count',
    'color': '22/a',
}
metric_info['checkpoint_identity_awareness_iaIdentityCollectorActiveDirectory'] = {
    'title': _('Identities logged in with Identity Collector Active Directory'),
    'unit': 'count',
    'color': '24/a',
}
metric_info['checkpoint_identity_awareness_iaIdentityCollectorCiscoISE'] = {
    'title': _('Identities logged in with Identity Collector Cisco ISE'),
    'unit': 'count',
    'color': '26/a',
}
metric_info['checkpoint_identity_awareness_iaTerminalServer'] = {
    'title': _('Identities logged in with terminal server'),
    'unit': 'count',
    'color': '32/a',
}
metric_info['checkpoint_identity_awareness_iaRemoteAccess'] = {
    'title': _('Identities logged in with Remote Access'),
    'unit': 'count',
    'color': '34/a',
}
metric_info['checkpoint_identity_awareness_iaIdentityWebAPI'] = {
    'title': _('Identities logged in with Identity Web API'),
    'unit': 'count',
    'color': '36/a',
}

metric_info['checkpoint_identity_awareness_iaAntiSpoffProtection'] = {
    'title': _('Users with an active Traffic Anti-Spoffing protection'),
    'unit': 'count',
    'color': '11/a',
}

metric_info['checkpoint_identity_awareness_iaDataTrans'] = {
    'title': _('How much data did  gateway transmitted'),
    'unit': 'count',
    'color': '42/a',
}

graph_info['checkpoint_identity_awareness_login_attempts'] = {
    'title': _('Check Point Identity Awareness login attempts'),
    'metrics': [
        ('checkpoint_identity_awareness_iaUnSuccUserLoginPass', '-stack'),
        ('checkpoint_identity_awareness_iaUnSuccMachLoginKerberos', '-stack'),
        ('checkpoint_identity_awareness_iaUnSuccUserLoginKerberos', '-stack'),
        ('checkpoint_identity_awareness_iaSuccUserLoginPass', 'stack'),
        ('checkpoint_identity_awareness_iaSuccMachLoginKerberos', 'stack'),
        ('checkpoint_identity_awareness_iaSuccUserLoginKerberos', 'stack'),
        ('checkpoint_identity_awareness_iaSuccMachLoginADQuery', 'stack'),
        ('checkpoint_identity_awareness_iaSuccUserLoginADQuery', 'stack'),
    ],
    'optional_metrics': [
        'checkpoint_identity_awareness_iaUnSuccUserLoginPass',
        'checkpoint_identity_awareness_iaUnSuccMachLoginKerberos',
        'checkpoint_identity_awareness_iaUnSuccUserLoginKerberos',
        'checkpoint_identity_awareness_iaSuccUserLoginPass',
        'checkpoint_identity_awareness_iaSuccMachLoginKerberos',
        'checkpoint_identity_awareness_iaSuccUserLoginKerberos',
        'checkpoint_identity_awareness_iaSuccMachLoginADQuery',
        'checkpoint_identity_awareness_iaSuccUserLoginADQuery',
    ],
}

graph_info['checkpoint_identity_awareness_ldap_queries'] = {
    'title': _('Check Point Identity Awareness LDAP queries'),
    'metrics': [
        ('checkpoint_identity_awareness_iaUnSuccUserLDAP', '-area'),
        ('checkpoint_identity_awareness_iaSuccUserLDAP', 'area'),
    ],
    'optional_metrics': [
        'checkpoint_identity_awareness_iaUnSuccUserLDAP',
        'checkpoint_identity_awareness_iaSuccUserLDAP',
    ]
}

graph_info['checkpoint_identity_awareness_auth_user_machine'] = {
    'title': _('Check Point Identity Awareness authenticated/unauthenticated users/machines'),
    'metrics': [
        ('checkpoint_identity_awareness_iaUnAuthUsers', 'stack'),
        ('checkpoint_identity_awareness_iaAuthUsersPass', 'stack'),
        ('checkpoint_identity_awareness_iaAuthMachKerberos', 'stack'),
        ('checkpoint_identity_awareness_iaAuthMachADQuery', '-stack'),
        ('checkpoint_identity_awareness_iaAuthUsersKerberos', '-stack'),
        ('checkpoint_identity_awareness_iaAuthUsersADQuery', 'stack'),
        ('checkpoint_identity_awareness_iaAuthUsers', 'line'),
    ],
    'optional_metrics': [
        'checkpoint_identity_awareness_iaUnAuthUsers',
        'checkpoint_identity_awareness_iaAuthUsersPass',
        'checkpoint_identity_awareness_iaAuthMachKerberos',
        'checkpoint_identity_awareness_iaAuthMachADQuery',
        'checkpoint_identity_awareness_iaAuthUsersKerberos',
        'checkpoint_identity_awareness_iaAuthUsersADQuery',
        'checkpoint_identity_awareness_iaAuthUsers',
    ]
}

graph_info['checkpoint_identity_awareness_loggid_in_users'] = {
    'title': _('Check Point Identity Awareness logged in users with'),
    'metrics': [
        ('checkpoint_identity_awareness_iaLoggedInCaptivePortal', 'stack'),
        ('checkpoint_identity_awareness_iaRADIUSAccounting', 'stack'),
        ('checkpoint_identity_awareness_iaIdentityWebAPI', 'stack'),
        ('checkpoint_identity_awareness_iaIdentityCollectorActiveDirectory', 'stack'),
        ('checkpoint_identity_awareness_iaIdentityCollectorCiscoISE', 'stack'),
        ('checkpoint_identity_awareness_iaRemoteAccess', 'stack'),
        ('checkpoint_identity_awareness_iaTerminalServer', 'stack'),
        ('checkpoint_identity_awareness_iaLoggedInAgent', 'stack'),
        ('checkpoint_identity_awareness_iaLoggedInADQuery', 'stack'),
    ],
    'optional_metrics': [
        'checkpoint_identity_awareness_iaLoggedInCaptivePortal',
        'checkpoint_identity_awareness_iaRADIUSAccounting',
        'checkpoint_identity_awareness_iaIdentityWebAPI',
        'checkpoint_identity_awareness_iaIdentityCollectorActiveDirectory',
        'checkpoint_identity_awareness_iaIdentityCollectorCiscoISE',
        'checkpoint_identity_awareness_iaRemoteAccess',
        'checkpoint_identity_awareness_iaTerminalServer',
        'checkpoint_identity_awareness_iaLoggedInAgent',
        'checkpoint_identity_awareness_iaLoggedInADQuery',
    ],
}

#graph_info.append({
#    'title': _('Check Point Identity Awareness users with an active Traffic Anti-Spoffing protection'),
#    'metrics': [
#        ('checkpoint_identity_awareness_iaAntiSpoffProtection', 'area'),
#    ],
#})

#graph_info.append({
#    'title': _('Check Point Identity Awareness How much data did the gateway transmitted'),
#    'metrics': [
#        ('checkpoint_identity_awareness_iaDataTrans', 'area'),
#    ],
#})

perfometer_info.append(('stacked', [
    {
        'type': 'logarithmic',
        'metric': 'checkpoint_identity_awareness_iaAuthUsers',
        'half_value': 2000.0,
        'exponent': 2,
    },
    {
        'type': 'logarithmic',
        'metric': 'checkpoint_identity_awareness_iaUnAuthUsers',
        'half_value': 2000.0,
        'exponent': 2,
    },
]))